@@ -5,6 +5,7 @@ A platform independent file lock that supports the with-statement.
    :no-value:
 
 """
+
 from __future__ import annotations
 
 import sys
@@ -24,7 +25,7 @@ __version__: str = version
 
 if sys.platform == "win32":  # pragma: win32 cover
     _FileLock: type[BaseFileLock] = WindowsFileLock
-else:  # pragma: win32 no cover
+else:  # pragma: win32 no cover # noqa: PLR5501
     if has_fcntl:
         _FileLock: type[BaseFileLock] = UnixFileLock
     else:
@@ -40,12 +41,12 @@ else:
 
 
 __all__ = [
-    "__version__",
+    "AcquireReturnProxy",
+    "BaseFileLock",
     "FileLock",
     "SoftFileLock",
     "Timeout",
     "UnixFileLock",
     "WindowsFileLock",
-    "BaseFileLock",
-    "AcquireReturnProxy",
+    "__version__",
 ]
